@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2005,2006 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2005-2007 -- leonerd@leonerd.org.uk
 
 package FCGI::Async::Request;
 
@@ -223,10 +223,10 @@ sub read_stdin_line
 {
    my $self = shift;
 
-   if( $self->{stdin} =~ s/^(.*[\r\n])+// ) {
+   if( $self->{stdin} =~ s/^(.*[\r\n])// ) {
       return $1;
    }
-   elsif( $self->{stdin} =~ s/^(.*)// ) {
+   elsif( $self->{stdin} =~ s/^(.+)// ) {
       return $1;
    }
    else {
